@@ -97,6 +97,21 @@ class AplicationPlugin(models.Model):
         app_label =u'auth'
         db_table = u'sic_aplicationplugin'
 
+class SaldosSms(models.Model):
+    id = models.AutoField(primary_key=True,db_column='ID_SIC_SMS_SALDO')
+    tipo=models.CharField(max_length=1, db_column='TIPO')
+    cliente=models.ForeignKey('Cliente', blank=True, null=True , db_column='CLIENTE_ID',on_delete=models.CASCADE)
+    cantidad=models.IntegerField(blank=True, null=True, db_column='CANTIDAD')
+    fecha=models.DateTimeField(auto_now=True, blank=True, null=True, db_column='FECHA')
+    persona_solicito=models.CharField(max_length=200, db_column='PERSONA_SOLICITO')
+    archivo = models.FileField(blank=True, null=True , upload_to='llaves', db_column='ARCHIVO')
+
+    class Meta:
+        db_table = u'sic_sms_saldos'
+        app_label='models_base'
+
+
+
 ################################################################
 ####                                                        ####
 ####                        CONFIGURACION                   ####
@@ -117,6 +132,7 @@ class RegistryLong(models.Model):
     
     class Meta:
         db_table = u'SIC_REGISTRY'
+        managed=False
 
 #FOLIOS FISCALES
 
@@ -666,6 +682,7 @@ class VentasDocumento(VentasDocumentoBase):
             if consecutivo_row:
                 consecutivo = consecutivo_row.consecutivo 
                 serie = consecutivo_row.serie
+            consecutivo_row.consecutivo = consecutivo_row.consecutivo + 1
 
         elif self.tipo == 'F':
             consecutivos_folios = FolioVenta.objects.using(connection_name).filter(tipo_doc = self.tipo, modalidad_facturacion = self.modalidad_facturacion)
@@ -674,15 +691,24 @@ class VentasDocumento(VentasDocumentoBase):
 
             consecutivo_row = first_or_none(consecutivos_folios)
             consecutivo = ''
-            if consecutivo_row:
+            if consecutivo_row: 
                 consecutivo = consecutivo_row.consecutivo 
                 serie = consecutivo_row.serie
                 if serie == u'@':
                     serie = ''
+            consecutivo_row.consecutivo = consecutivo_row.consecutivo + 1
+        elif self.tipo == 'S':
+            consecutivos_folios=Registry.objects.get( nombre = 'SIC_Pedidos_Crm_Url_Consecutivo_Solicitud').get_value()
+            consecutivo_row=Registry.objects.get( nombre = 'SIC_Pedidos_Crm_Url_Consecutivo_Solicitud')
+            serie='S'
+            consecutivo = int(consecutivos_folios) + 1
+            consecutivo_row.valor=str(consecutivo)
+            print(consecutivo)
+
 
         folio = '%s%s'% (serie,("%09d" % int(consecutivo))[len(serie):]) 
-
-        consecutivo_row.consecutivo = consecutivo_row.consecutivo + 1
+        print("******",folio)
+        
         consecutivo_row.save(using=connection_name)
 
         return folio, consecutivo
@@ -971,3 +997,16 @@ class Log(models.Model):
 
     class Meta:
         db_table = u'SIC_LOG'
+        managed=False
+
+class ClienteUsuario(models.Model):
+    id=models.AutoField(primary_key=True, db_column='CLIENTE_USUARIO_ID')
+    cliente=models.ForeignKey('Cliente', blank=True, null=True, db_column='CLIENTE_ID',on_delete=models.CASCADE)
+    usuario=models.IntegerField(blank=True, null=True, db_column='USUARIO_ID')
+
+    class Meta:
+        db_table = 'SIC_CLIENTE_USUARIO'
+        app_label = 'models_base'
+
+
+
